@@ -69,10 +69,13 @@ class FileIOModel(Atom):
     file_path = Str()
     load_status = Str()
     data_sets = Typed(OrderedDict)
-    img_dict = Dict()
-    param_fit = Dict()
     file_channel_list = List()
 
+    img_dict = Dict()
+    img_dict_keys = List()
+    img_dict_default_selected_item = Int()
+    img_dict_is_updated = Bool(False)
+
     runid = Int(-1)  # Run ID of the current run
     runuid = Str()  # Run UID of the current run
 
@@ -119,8 +122,8 @@ class FileIOModel(Atom):
     #   its value should not be used for computations!!!
     incident_energy_set = Float(0.0)
 
-    def __init__(self, **kwargs):
-        self.working_directory = kwargs['working_directory']
+    def __init__(self, *, working_directory):
+        self.working_directory = working_directory
         self.mask_data = None
 
         # Display PyXRF version in the window title
@@ -262,6 +265,9 @@ class FileIOModel(Atom):
         self.roi_col_end = -1
 
         self.img_dict = {}
+        self.img_dict_keys = []
+        self.img_dict_default_selected_item = 0
+
         self.data_sets = OrderedDict()
         self.scan_metadata = ScanMetadataXRF()
         self._metadata_update_program_state()
@@ -289,6 +295,7 @@ class FileIOModel(Atom):
                          self.file_name,
                          load_each_channel=self.load_each_channel)
         self.img_dict = img_dict
+        self.update_img_dict()
 
         # Replace relative scan ID with true scan ID.
 
@@ -328,6 +335,62 @@ class FileIOModel(Atom):
                                    f"{map_size_other} != {map_size}")
         return map_size
 
+    def update_img_dict(self, img_dict_additional=None):
+        if img_dict_additional is None:
+            img_dict_additional = {}
+
+        new_keys = list(img_dict_additional.keys())
+        selected_key = new_keys[0] if new_keys else None
+
+        self.img_dict.update(img_dict_additional)
+        self.img_dict_keys = self._get_img_dict_keys()
+
+        if selected_key is None:
+            selected_item = 1 if self.img_dict_keys else 0
+        else:
+            selected_item = self.img_dict_keys.index(selected_key) + 1
+
+        self.select_img_dict_item(selected_item, always_update=True)
+
+    def select_img_dict_item(self, selected_item, *, always_update=False):
+        """
+        Select the set of image maps.
+
+        Parameters
+        ----------
+        selected_item : int
+            Selected item (set of maps) in the `self.img_dict`. Range: `0..len(self.img_dict)`.
+            0 - no dataset is selected.
+        always_update : boolean
+            True - update even if the item is already selected.
+        """
+        # Select no dataset if index is out of range
+        selected_item = selected_item if (0 <= selected_item <= len(self.img_dict)) else 0
+
+        # Don't update the plots if the item is already selected
+        if always_update or (selected_item != self.img_dict_default_selected_item):
+            self.img_dict_default_selected_item = selected_item
+            self.img_dict_is_updated = False
+            self.img_dict_is_updated = True
+
+    def _get_img_dict_keys(self):
+        key_suffix = [r"scaler$", r"det\d+_roi$", r"roi$", r"det\d+_fit$", r"fit$"]
+        keys = [[] for _ in range(len(key_suffix) + 1)]
+        for k in self.img_dict.keys():
+            found = False
+            for n, suff in enumerate(key_suffix):
+                if re.search(suff, k):
+                    keys[n + 1].append(k)
+                    found = True
+                    break
+            if not found:
+                keys[0].append(k)
+        keys_sorted = []
+        for n in reversed(range(len(keys))):
+            keys[n].sort()
+            keys_sorted += keys[n]
+        return keys_sorted
+
     def get_dataset_preview_count_map_range(self, *, selected_only=False):
         """
         Returns the range of the Total Count Maps in the loaded datasets.
@@ -390,20 +453,6 @@ class FileIOModel(Atom):
 
         requires databroker
         """
-        # if self.h_num != 0 and self.v_num != 0:
-        #     datashape = [self.v_num, self.h_num]
-
-        #  one way to cache data is to save as h5 file, to be considered later
-        # tmp_wd = '~/.tmp/'
-        # if not os.path.exists(tmp_wd):
-        #     os.makedirs(tmp_wd)
-        # fpath = os.path.join(tmp_wd, self.fname_from_db)
-        # if not os.path.exists(fpath):
-        #     make_hdf(self.runid, fname=fpath)
-        # self.img_dict, self.data_sets = file_handler(tmp_wd,
-        #                                             self.fname_from_db,
-        #                                             load_each_channel=self.load_each_channel)
-
         # Clear data. If reading the file fails, then old data should not be kept.
         self.file_channel_list = []
         self.clear()
@@ -443,21 +492,6 @@ class FileIOModel(Atom):
 
         self.file_channel_list = list(self.data_sets.keys())
 
-        # Disable loading from 'analysis store' for now (because there is no 'analysis store')
-        # ----------------------------------------------------------------
-        # # Load results from the analysis store
-        # from .data_to_analysis_store import get_analysis_result
-        # hdr = get_analysis_result(self.runid)
-        # if hdr is not None:
-        #     d1 = hdr.table(stream_name='primary')
-        #     # d2 = hdr.table(stream_name='spectrum')
-        #     self.param_fit = hdr.start.processor_parameters
-        #     # self.data = d2['summed_spectrum_experiment']
-        #     fit_result = {k: v for k, v in zip(d1['element_name'], d1['map'])}
-        #     # tmp = {k: v for k, v in self.img_dict.items()}
-        #     img_dict['scan2D_{}_fit'.format(self.runid)] = fit_result
-        # ----------------------------------------------------------------
-
         self.img_dict = img_dict
 
         self.data_ready = True
@@ -620,9 +654,9 @@ class DataSelection(Atom):
     both are set.
 
     There are some unresolved questions about logic:
-    - what is exactly the role of `self.data`? It is definitely used when
+    - what is exactly the role of `self.io_model.data`? It is definitely used when
     the data is plotted, but is it ever bypassed by directly calling `get_sum`?
-    If the data is always accessed using `self.data`, then storing the averaged
+    If the data is always accessed using `self.io_model.data`, then storing the averaged
     spectrum in cache is redundant, but since the array is small, it's not
     much overhead to keep another copy just in case.
     - there is no obvious way to set `point1` and `point2`
@@ -1713,17 +1747,6 @@ def read_MAPS(working_directory,
     return img_dict, data_sets, mdata
 
 
-def get_roi_sum(namelist, data_range, data):
-    data_temp = dict()
-    for i in range(len(namelist)):
-        lowv = data_range[i, 0]
-        highv = data_range[i, 1]
-        data_sum = np.sum(data[:, :, lowv: highv], axis=2)
-        data_temp.update({namelist[i]: data_sum})
-        # data_temp.update({namelist[i].replace(' ', '_'): data_sum})
-    return data_temp
-
-
 def get_fit_data(namelist, data):
     """
     Read fit data from h5 file. This is to be moved to filestore part.
